<?php
/*
Plugin Name: Nostalgia Theme About
Plugin URI: https://1.envato.market/quanticalabs-portfolio
Description: Nostalgia Theme About Plugin
Author: QuanticaLabs
Author URI: https://1.envato.market/quanticalabs-portfolio
Version: 1.1
Text Domain: nostalgia_about
*/

//translation
function nostalgia_about_load_textdomain()
{
	load_plugin_textdomain("nostalgia_about", false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'nostalgia_about_load_textdomain');
//custom post type - about
function nostalgia_about_init() 
{  
	$labels = array(
		'name' => _x('About', 'post type general name', 'nostalgia_about'),
		'singular_name' => _x('About Item', 'post type singular name', 'nostalgia_about'),
		'add_new' => _x('Add New', 'nostalgia_about', 'nostalgia_about'),
		'add_new_item' => __('Add New About Item', 'nostalgia_about'),
		'edit_item' => __('Edit About Item', 'nostalgia_about'),
		'new_item' => __('New About Item', 'nostalgia_about'),
		'all_items' => __('All About Items', 'nostalgia_about'),
		'view_item' => __('View About Item', 'nostalgia_about'),
		'search_items' => __('Search About Item', 'nostalgia_about'),
		'not_found' =>  __('No About items found', 'nostalgia_about'),
		'not_found_in_trash' => __('No about items found in Trash', 'nostalgia_about'), 
		'parent_item_colon' => '',
		'menu_name' => __("About", 'nostalgia_about')
	);
	$args = array(  
		"labels" => $labels, 
		"public" => true,  
		"show_ui" => true,  
		"capability_type" => "post",  
		"menu_position" => 20,
		"hierarchical" => false,  
		"rewrite" => true,  
		"supports" => array("title", "editor", "page-attributes")  
	);
	register_post_type("nostalgia_about", $args);  
	
	register_taxonomy("nostalgia_about_category", array("nostalgia_about"), array("label" => __("Categories", 'nostalgia_about'), "singular_label" => __("Category", 'nostalgia_about'), "rewrite" => true)); 
}  
add_action("init", "nostalgia_about_init");

//Adds a box to the main column on the About edit screens
function nostalgia_add_about_custom_box() 
{
    add_meta_box( 
        "about_config",
        __("Options", 'nostalgia_about'),
        "nostalgia_inner_about_custom_box",
        "nostalgia_about",
		"normal",
		"high"
    );
}
add_action("add_meta_boxes", "nostalgia_add_about_custom_box");

//Prints the box content
function nostalgia_inner_about_custom_box($post) 
{
	//Use nonce for verification
	wp_nonce_field(plugin_basename( __FILE__ ), "nostalgia_about_noncename");
	
	$icon = get_post_meta($post->ID, "icon", true);

	echo '
	<table>
		<tr>
			<td>
				<label for="icon">' . __('Icon', 'nostalgia_about') . ':</label>
			</td>
			<td>
				<select style="width: 120px;" id="icon" name="icon">
					<option value=""' . ($icon=="" ? ' selected="selected"' : '') . '>-</option>
					<option value="app"' . ($icon=="app" ? ' selected="selected"' : '') . '>' . __('app', 'nostalgia_about') . '</option>
					<option value="binoculars"' . ($icon=="binoculars" ? ' selected="selected"' : '') . '>' . __('binoculars', 'nostalgia_about') . '</option>
					<option value="briefcase"' . ($icon=="briefcase" ? ' selected="selected"' : '') . '>' . __('briefcase', 'nostalgia_about') . '</option>
					<option value="camera"' . ($icon=="camera" ? ' selected="selected"' : '') . '>' . __('camera', 'nostalgia_about') . '</option>
					<option value="document"' . ($icon=="document" ? ' selected="selected"' : '') . '>' . __('document', 'nostalgia_about') . '</option>
					<option value="heart"' . ($icon=="heart" ? ' selected="selected"' : '') . '>' . __('heart', 'nostalgia_about') . '</option>
					<option value="image"' . ($icon=="image" ? ' selected="selected"' : '') . '>' . __('image', 'nostalgia_about') . '</option>
					<option value="lightbulb"' . ($icon=="lightbulb" ? ' selected="selected"' : '') . '>' . __('lightbulb', 'nostalgia_about') . '</option>
					<option value="people"' . ($icon=="people" ? ' selected="selected"' : '') . '>' . __('people', 'nostalgia_about') . '</option>
					<option value="post"' . ($icon=="post" ? ' selected="selected"' : '') . '>' . __('post', 'nostalgia_about') . '</option>
				</select>
			</td>
		</tr>
	</table>
	';
}

//When the post is saved, saves our custom data
function nostalgia_save_about_postdata($post_id) 
{
	//verify if this is an auto save routine. 
	//if it is our form has not been submitted, so we dont want to do anything
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
		return;

	//verify this came from the our screen and with proper authorization,
	//because save_post can be triggered at other times
	if (!isset($_POST['nostalgia_about_noncename']) || !wp_verify_nonce($_POST['nostalgia_about_noncename'], plugin_basename( __FILE__ )))
		return;


	//Check permissions
	if(!current_user_can('edit_post', $post_id))
		return;

	//OK, we're authenticated: we need to find and save the data
	update_post_meta($post_id, "icon", $_POST["icon"]);
}
add_action("save_post", "nostalgia_save_about_postdata");

//custom about items list
function nostalgia_about_edit_columns($columns)
{
	$new_columns = array(  
		"cb" => "<input type=\"checkbox\" />",  
		"title" => _x('About Item', 'post type singular name', 'nostalgia_about'),   
		"icon" => __('Icon', 'nostalgia_about'),
		"nostalgia_about_category" => __('Categories', 'nostalgia_about'),
		"date" => __('Date', 'nostalgia_about') 
	);

	return array_merge($new_columns, $columns);  
}  
add_filter("manage_edit-nostalgia_about_columns", "nostalgia_about_edit_columns");

function manage_nostalgia_about_posts_custom_column($column)
{
	global $post;
	switch ($column)  
	{
		case "icon":   
			echo get_post_meta($post->ID, "icon", true);  
			break;
		case "nostalgia_about_category":
			echo get_the_term_list($post->ID, "nostalgia_about_category", '', ', ',''); 
			break;
	}  
}
add_action("manage_nostalgia_about_posts_custom_column", "manage_nostalgia_about_posts_custom_column");

//about
function nostalgia_about_shortcode($atts)
{
	extract(shortcode_atts(array(
		"category" => "",
	), $atts));
	
	$output = "";
	$output .= '<ul class="no-list list-about">';
	//get pages
	query_posts(array( 
		'post_type' => 'nostalgia_about',
		'posts_per_page' => '-1',
		'post_status' => 'publish',
		'nostalgia_about_category' => $category,
		'orderby' => 'menu_order', 
		'order' => 'ASC'
	));
	$i = 0;
	if(have_posts()) : while (have_posts()) : the_post();
		$icon = get_post_meta(get_the_ID(), "icon", true);
		$output .= '
		<li class="' . ($i%2==0 ? 'left' : 'right') . '">
			<h3>' . get_the_title() . '</h3>
			<p>
				' . ($icon!="" ? '<span class="icon-big icon-' . $icon . '"></span>' : '') . '
				' . do_shortcode(get_the_content()) . '
			</p>
		</li>';
		$i++;
	endwhile; endif;
	$output .= '</ul>';
	return $output;
}
add_shortcode("nostalgia_about", "nostalgia_about_shortcode");
?>