<?php
/*
Plugin Name: Nostalgia Theme Portfolio
Plugin URI: https://1.envato.market/quanticalabs-portfolio
Description: Nostalgia Theme Portfolio Plugin
Author: QuanticaLabs
Author URI: https://1.envato.market/quanticalabs-portfolio
Version: 1.1
Text Domain: nostalgia_portfolio
*/

//translation
function nostalgia_portfolio_load_textdomain()
{
	load_plugin_textdomain("nostalgia_portfolio", false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'nostalgia_portfolio_load_textdomain');
//custom post type - portfolio
function nostalgia_portfolio_init()
{
	$labels = array(
		'name' => _x('Portfolio', 'post type general name', 'nostalgia_portfolio'),
		'singular_name' => _x('Portfolio Item', 'post type singular name', 'nostalgia_portfolio'),
		'add_new' => _x('Add New', 'nostalgia_portfolio', 'nostalgia_portfolio'),
		'add_new_item' => __('Add New Portfolio Item', 'nostalgia_portfolio'),
		'edit_item' => __('Edit Portfolio Item', 'nostalgia_portfolio'),
		'new_item' => __('New Portfolio Item', 'nostalgia_portfolio'),
		'all_items' => __('All Portfolio Items', 'nostalgia_portfolio'),
		'view_item' => __('View Portfolio Item', 'nostalgia_portfolio'),
		'search_items' => __('Search Portfolio Item', 'nostalgia_portfolio'),
		'not_found' =>  __('No portfolio items found', 'nostalgia_portfolio'),
		'not_found_in_trash' => __('No portfolio items found in Trash', 'nostalgia_portfolio'), 
		'parent_item_colon' => '',
		'menu_name' => __("Portfolio", 'nostalgia_portfolio')
	);
	$args = array(  
		"labels" => $labels, 
		"public" => true,  
		"show_ui" => true,  
		"capability_type" => "post",  
		"menu_position" => 20,
		"hierarchical" => false,  
		"rewrite" => true,  
		"supports" => array("title", "editor", "thumbnail", "page-attributes")  
	);
	register_post_type("nostalgia_portfolio", $args);  
	
	register_taxonomy("nostalgia_portfolio_category", array("nostalgia_portfolio"), array("label" => __("Categories", 'nostalgia_portfolio'), "singular_label" => __("Category", 'nostalgia_portfolio'), "rewrite" => true, "hierarchical" => true)); 
}  
add_action("init", "nostalgia_portfolio_init");

//Adds a box to the main column on the Portfolio edit screens
function nostalgia_add_portfolio_custom_box() 
{
    add_meta_box( 
        "portfolio_config",
        __("Options", 'nostalgia_portfolio'),
        "nostalgia_inner_portfolio_custom_box",
        "nostalgia_portfolio",
		"normal",
		"high"
    );
}
add_action("add_meta_boxes", "nostalgia_add_portfolio_custom_box");

//Prints the box content
function nostalgia_inner_portfolio_custom_box($post) 
{
	//Use nonce for verification
	wp_nonce_field(plugin_basename( __FILE__ ), "nostalgia_portfolio_noncename");

	//The actual fields for data entry
	$external_url_target = get_post_meta($post->ID, "external_url_target", true);
	$portfolio_description_location = get_post_meta($post->ID, "portfolio_description_location", true);
	$images = get_post_meta($post->ID, "images", true);
	$images_titles = get_post_meta($post->ID, "images_titles", true);
	$features_images_loop = get_post_meta($post->ID, "features_images_loop", true);
	echo '
	<table>
		<tr>
			<td>
				<label for="portfolio_video_url">' . __('Video URL (optional)', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_video_url" name="portfolio_video_url" value="' . esc_attr(get_post_meta($post->ID, "video_url", true)) . '" />
				<span class="description">' . __("For Vimeo please use http://player.vimeo.com/video/%video_id% For YouTube: http://youtube.com/embed/%video_id%", 'nostalgia_portfolio') . '</span>
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_audio_url">' . __('Audio URL (optional)', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_audio_url" name="portfolio_audio_url" value="' . esc_attr(get_post_meta($post->ID, "audio_url", true)) . '" />
				<input type="button" class="button" name="nostalgia_upload_button" id="portfolio_audio_url_button" value="' . __('Browse', 'nostalgia_portfolio') . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_iframe_url">' . __('Ifame URL (optional)', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_iframe_url" name="portfolio_iframe_url" value="' . esc_attr(get_post_meta($post->ID, "iframe_url", true)) . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_external_url">' . __('External URL (optional)', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="portfolio_external_url" name="portfolio_external_url" value="' . esc_attr(get_post_meta($post->ID, "external_url", true)) . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_external_url_target">' . __('External URL target', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<select id="portfolio_external_url_target" name="portfolio_external_url_target">
					<option value="same_window"' . ($external_url_target=="same_window" ? ' selected="selected"' : '') . '>' . __('same window', 'nostalgia_portfolio') . '</option>
					<option value="new_window"' . ($external_url_target=="new_window" ? ' selected="selected"' : '') . '>' . __('new window', 'nostalgia_portfolio') . '</option>
				</select>
			</td>
		</tr>
		<tr>
			<td>
				<label for="portfolio_description_location">' . __('Description location', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<select id="portfolio_description_location" name="portfolio_description_location">
					<option value="item"' . ($portfolio_description_location=="item" ? ' selected="selected"' : '') . '>' . __('item', 'nostalgia_portfolio') . '</option>
					<option value="lightbox"' . ($portfolio_description_location=="lightbox" ? ' selected="selected"' : '') . '>' . __('lightbox', 'nostalgia_portfolio') . '</option>
					<option value="both"' . ($portfolio_description_location=="both" ? ' selected="selected"' : '') . '>' . __('both', 'nostalgia_portfolio') . '</option>
				</select>
			</td>
		</tr>
		<tr valign="top">
			<th colspan="2" scope="row" style="font-weight: bold;">
				' . __('Additional featured images', 'nostalgia_portfolio') . '
			</th>
		</tr>';
		$images_count = count(array_values(array_filter((array)$images)));
		if($images_count==0)
			$images_count = 3;
		for($i=0; $i<$images_count; $i++)
		{
		echo '
		<tr class="image_url_row">
			<td>
				<label>' . __('Image url', 'nostalgia_portfolio') . " " . ($i+1) . '</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="nostalgia_image_url_' . ($i+1) . '" name="images[]" value="' . (isset($images[$i]) ? esc_attr($images[$i]) : '') . '" />
				<input type="button" class="button" name="nostalgia_upload_button" id="nostalgia_image_url_button_' . ($i+1) . '" value="' . __('Browse', 'nostalgia_portfolio') . '" />
			</td>
		</tr>
		<tr class="image_title_row">
			<td>
				<label>' . __('Image title', 'nostalgia_portfolio') . " " . ($i+1) . '</label>
			</td>
			<td>
				<input class="regular-text" type="text" id="nostalgia_image_title_' . ($i+1) . '" name="images_titles[]" value="' . (isset($images_titles[$i]) ? esc_attr($images_titles[$i]) : '') . '" />
			</td>
		</tr>';
		}
		echo '
		<tr>
			<td></td>
			<td>
				<input type="button" class="button" name="nostalgia_add_new_button" id="nostalgia_add_new_button_image" value="' . __('Add image', 'nostalgia_portfolio') . '" />
			</td>
		</tr>
		<tr>
			<td>
				<label for="features_images_loop">' . __('Featured images loop', 'nostalgia_portfolio') . ':</label>
			</td>
			<td>
				<select id="features_images_loop" name="features_images_loop">
					<option value="yes"' . ($features_images_loop=="yes" ? ' selected="selected"' : '') . '>' . __('yes', 'nostalgia_portfolio') . '</option>
					<option value="no"' . ($features_images_loop=="no" ? ' selected="selected"' : '') . '>' . __('no', 'nostalgia_portfolio') . '</option>
				</select>
			</td>
		</tr>
	</table>
	';
}

//When the post is saved, saves our custom data
function nostalgia_save_portfolio_postdata($post_id) 
{
	//verify if this is an auto save routine. 
	//if it is our form has not been submitted, so we dont want to do anything
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
		return;

	//verify this came from the our screen and with proper authorization,
	//because save_post can be triggered at other times
	if (!isset($_POST['nostalgia_portfolio_noncename']) || !wp_verify_nonce($_POST['nostalgia_portfolio_noncename'], plugin_basename( __FILE__ )))
		return;


	//Check permissions
	if(!current_user_can('edit_post', $post_id))
		return;

	//OK, we're authenticated: we need to find and save the data
	update_post_meta($post_id, "video_url", $_POST["portfolio_video_url"]);
	update_post_meta($post_id, "audio_url", $_POST["portfolio_audio_url"]);
	update_post_meta($post_id, "iframe_url", $_POST["portfolio_iframe_url"]);
	update_post_meta($post_id, "external_url", $_POST["portfolio_external_url"]);
	update_post_meta($post_id, "external_url_target", $_POST["portfolio_external_url_target"]);
	update_post_meta($post_id, "portfolio_description_location", $_POST["portfolio_description_location"]);
	update_post_meta($post_id, "images", array_filter($_POST["images"]));
	update_post_meta($post_id, "images_titles", array_filter($_POST["images_titles"]));
	update_post_meta($post_id, "features_images_loop", $_POST["features_images_loop"]);
}
add_action("save_post", "nostalgia_save_portfolio_postdata");

//custom portfolio items list
function nostalgia_portfolio_edit_columns($columns)
{
	$new_columns = array(  
		"cb" => "<input type=\"checkbox\" />",  
		"title" => _x('Portfolio Item', 'post type singular name', 'nostalgia_portfolio'),   
		"video_url" => __('Video URL', 'nostalgia_portfolio'),
		"audio_url" => __('Audio URL', 'nostalgia_portfolio'),
		"iframe_url" => __('Iframe URL', 'nostalgia_portfolio'),
		"external_url" => __('External URL', 'nostalgia_portfolio'),
		"nostalgia_portfolio_category" => __('Categories', 'nostalgia_portfolio'),
		"date" => __('Date', 'nostalgia_portfolio')
	);    

	return array_merge($new_columns, $columns);  
}  
add_filter("manage_edit-nostalgia_portfolio_columns", "nostalgia_portfolio_edit_columns");

function manage_nostalgia_portfolio_posts_custom_column($column)
{
	global $post;
	switch ($column)  
	{
		case "video_url":   
			echo get_post_meta($post->ID, "video_url", true);  
			break;
		case "audio_url":   
			echo get_post_meta($post->ID, "audio_url", true);  
			break;
		case "iframe_url":   
			echo get_post_meta($post->ID, "iframe_url", true);  
			break;
		case "external_url":   
			echo get_post_meta($post->ID, "external_url", true);  
			break;
		case "nostalgia_portfolio_category":
			echo get_the_term_list($post->ID, "nostalgia_portfolio_category", '', ', ',''); 
			break;
	}  
}
add_action("manage_nostalgia_portfolio_posts_custom_column", "manage_nostalgia_portfolio_posts_custom_column");

//portfolio
function nostalgia_portfolio_tab($categories="", $i="", $open="", $default_tab_title="")
{	
	query_posts(array( 
		'post_type' => 'nostalgia_portfolio',
		'posts_per_page' => '-1',
		'post_status' => 'publish',
		'nostalgia_portfolio_category' => ($categories!="" ? $categories[$i] : ""),
		'orderby' => 'menu_order', 
		'order' => 'ASC'
	));
	$output = "";
	if(have_posts()):
		$output .= '<h3' . ($categories!="" && $open==$categories[$i] ? ' class="ui-state-active"' : '') . '><a href="#">';
		if($categories!="")
		{
			$term = get_term_by('slug', $categories[$i], "nostalgia_portfolio_category");
			$ancestors = get_ancestors($term->term_id, "nostalgia_portfolio_category");
			for($j=count($ancestors)-1; $j>=0; $j--)
				$output .= get_term($ancestors[$j], "nostalgia_portfolio_category")->name . " / ";
			$output .= $term->name;
		}
		else
			$output .= $default_tab_title;
		$output .= '</a></h3>
		<div><ul class="image-list">';
		$j=0;
		while(have_posts()): the_post();
			if(has_post_thumbnail()) 
			{
				$video_url = get_post_meta(get_the_ID(), "video_url", true);
				if($video_url!="")
					$large_image_url = $video_url;
				else
				{
					$attachment_image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), "large");
					$large_image_url = $attachment_image[0];
				}
				$audio_url = get_post_meta(get_the_ID(), "audio_url", true);
				$external_url = get_post_meta(get_the_ID(), "external_url", true);
				$external_url_target = get_post_meta(get_the_ID(), "external_url_target", true);
				$iframe_url = get_post_meta(get_the_ID(), "iframe_url", true);
				$portfolio_description_location = get_post_meta(get_the_ID(), "portfolio_description_location", true);
				$images = get_post_meta(get_the_ID(), "images", true);
				$images_titles = get_post_meta(get_the_ID(), "images_titles", true);
				$images_count = count(array_values(array_filter((array)$images)));
				$features_images_loop =  get_post_meta(get_the_ID(), "features_images_loop", true);
				$output .= '
				<li class="' . ($j%2==0 ? 'left' : 'right') . '">
					<a' . ($categories!="" && !$images_count ? ' rel="' . esc_attr($categories[$i]) . '"' : ($images_count ? ' rel="featured_' . esc_attr(get_the_ID()) . '"' : '' )) . ($external_url!="" && $external_url_target=="new_window" ? ' target="_blank"' : '') . ' href="' . ($external_url=="" && $audio_url=="" ? ($iframe_url!="" ? esc_url($iframe_url) : esc_url($large_image_url)) : ($audio_url=="" ? esc_url($external_url) : esc_url($audio_url))) . '"' . ($external_url=="" && $audio_url=="" ? ' class="fancybox-' . ($video_url!="" ? 'video' : ($iframe_url!="" ? 'iframe' : 'image')) . ($features_images_loop=='yes' ? ' cyclic' : '') . '"' : ($audio_url!="" ? ' class="audio-item"' : '')) . ($portfolio_description_location=='lightbox' || $portfolio_description_location=='both' ? ' title="' . esc_attr(get_the_content()) . '"' : '' ) . '>'
						. get_the_post_thumbnail(get_the_ID(), "nostalgia-portfolio-thumb", array("alt" => get_the_title(), "title" => "")) .
						'<span/>
					</a>
					<div class="image-list-caption">
						<div class="image-list-caption-title">' . get_the_title() . '</div>
						' . ($portfolio_description_location=='item' || $portfolio_description_location=='both' ? '<div class="image-list-caption-subtitle">' . get_the_content() . '</div>' : '') . '
					</div>';
				if($external_url=="" && $audio_url=="" && $video_url=="" && $iframe_url=="")
				{
					for($k=0; $k<$images_count; $k++)
						$output .= '<a href="' . esc_url($images[$k]) . '" title="' . esc_attr($images_titles[$k]) . '" class="fancybox-image fancybox-hidden' . ($features_images_loop=='yes' ? ' cyclic' : '') . '" rel="featured_' . esc_attr(get_the_ID()) . '">&nbsp;</a>';
				}
				$output .= '</li>';
				$j++;
			}
		endwhile; 
		$output .= '</ul></div>';
	endif;
	return $output;
}
function nostalgia_portfolio_shortcode($atts)
{
	extract(shortcode_atts(array(
		"category" => "",
		"open" => "false",
		"default_tab_title" => "Portfolio Items"
	), $atts));
	
	$output = "";
	if(wp_count_posts("nostalgia_portfolio")->publish)
	{
		$categories = array_values(array_filter(explode(',', $category)));
		$categoriesCount = count($categories);
		$output .= '<div class="nostalgia-accordion">';
		if($categoriesCount)
		{
			for($i=0; $i<$categoriesCount; $i++)
				$output .= nostalgia_portfolio_tab($categories, $i, $open);
		}
		else
			$output .= nostalgia_portfolio_tab("", "", $open, $default_tab_title);
		$output .= '</div>';
	}
	return $output;
}
add_shortcode("nostalgia_portfolio", "nostalgia_portfolio_shortcode");
?>