<?php
/*
Plugin Name: Nostalgia Theme Service
Plugin URI: https://1.envato.market/quanticalabs-portfolio
Description: Nostalgia Theme Service Plugin
Author: QuanticaLabs
Author URI: https://1.envato.market/quanticalabs-portfolio
Version: 1.1
Text Domain: nostalgia_service
*/

//translation
function nostalgia_service_load_textdomain()
{
	load_plugin_textdomain("nostalgia_service", false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'nostalgia_service_load_textdomain');
//custom post type - service
function nostalgia_service_init() 
{  
	$labels = array(
		'name' => _x('Service', 'post type general name', 'nostalgia_service'),
		'singular_name' => _x('Service Item', 'post type singular name', 'nostalgia_service'),
		'add_new' => _x('Add New', 'nostalgia_service', 'nostalgia_service'),
		'add_new_item' => __('Add New Service Item', 'nostalgia_service'),
		'edit_item' => __('Edit Service Item', 'nostalgia_service'),
		'new_item' => __('New Service Item', 'nostalgia_service'),
		'all_items' => __('All Service Items', 'nostalgia_service'),
		'view_item' => __('View Service Item', 'nostalgia_service'),
		'search_items' => __('Search Service Item', 'nostalgia_service'),
		'not_found' =>  __('No Service items found', 'nostalgia_service'),
		'not_found_in_trash' => __('No service items found in Trash', 'nostalgia_service'), 
		'parent_item_colon' => '',
		'menu_name' => __("Service", 'nostalgia_service')
	);
	$args = array(  
		"labels" => $labels, 
		"public" => true,  
		"show_ui" => true,  
		"capability_type" => "post",  
		"menu_position" => 20,
		"hierarchical" => false,  
		"rewrite" => true,  
		"supports" => array("title", "editor", "page-attributes")  
	);
	register_post_type("nostalgia_service", $args);  
	
	register_taxonomy("nostalgia_service_category", array("nostalgia_service"), array("label" => __("Categories", 'nostalgia_service'), "singular_label" => __("Category", 'nostalgia_service'), "rewrite" => true)); 
}  
add_action("init", "nostalgia_service_init");

//Adds a box to the main column on the Service edit screens
function nostalgia_add_service_custom_box() 
{
    add_meta_box( 
        "service_config",
        __("Options", 'nostalgia_service'),
        "nostalgia_inner_service_custom_box",
        "nostalgia_service",
		"normal",
		"high"
    );
}
add_action("add_meta_boxes", "nostalgia_add_service_custom_box");

//Prints the box content
function nostalgia_inner_service_custom_box($post) 
{
	//Use nonce for verification
	wp_nonce_field(plugin_basename( __FILE__ ), "nostalgia_service_noncename");
	
	$icon = get_post_meta($post->ID, "icon", true);

	echo '
	<table>
		<tr>
			<td>
				<label for="icon">' . __('Icon', 'nostalgia_service') . ':</label>
			</td>
			<td>
				<select style="width: 120px;" id="icon" name="icon">
					<option value=""' . ($icon=="" ? ' selected="selected"' : '') . '>-</option>
					<option value="app"' . ($icon=="app" ? ' selected="selected"' : '') . '>' . __('app', 'nostalgia_service') . '</option>
					<option value="binoculars"' . ($icon=="binoculars" ? ' selected="selected"' : '') . '>' . __('binoculars', 'nostalgia_service') . '</option>
					<option value="briefcase"' . ($icon=="briefcase" ? ' selected="selected"' : '') . '>' . __('briefcase', 'nostalgia_service') . '</option>
					<option value="camera"' . ($icon=="camera" ? ' selected="selected"' : '') . '>' . __('camera', 'nostalgia_service') . '</option>
					<option value="document"' . ($icon=="document" ? ' selected="selected"' : '') . '>' . __('document', 'nostalgia_service') . '</option>
					<option value="heart"' . ($icon=="heart" ? ' selected="selected"' : '') . '>' . __('heart', 'nostalgia_service') . '</option>
					<option value="image"' . ($icon=="image" ? ' selected="selected"' : '') . '>' . __('image', 'nostalgia_service') . '</option>
					<option value="lightbulb"' . ($icon=="lightbulb" ? ' selected="selected"' : '') . '>' . __('lightbulb', 'nostalgia_service') . '</option>
					<option value="people"' . ($icon=="people" ? ' selected="selected"' : '') . '>' . __('people', 'nostalgia_service') . '</option>
					<option value="post"' . ($icon=="post" ? ' selected="selected"' : '') . '>' . __('post', 'nostalgia_service') . '</option>
				</select>
			</td>
		</tr>
	</table>
	';
}

//When the post is saved, saves our custom data
function nostalgia_save_service_postdata($post_id) 
{
	//verify if this is an auto save routine. 
	//if it is our form has not been submitted, so we dont want to do anything
	if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) 
		return;

	//verify this came from the our screen and with proper authorization,
	//because save_post can be triggered at other times
	if (!isset($_POST['nostalgia_service_noncename']) || !wp_verify_nonce($_POST['nostalgia_service_noncename'], plugin_basename( __FILE__ )))
		return;


	//Check permissions
	if(!current_user_can('edit_post', $post_id))
		return;

	//OK, we're authenticated: we need to find and save the data
	update_post_meta($post_id, "icon", $_POST["icon"]);
}
add_action("save_post", "nostalgia_save_service_postdata");

//custom service items list
function nostalgia_service_edit_columns($columns)
{
	$new_columns = array(  
		"cb" => "<input type=\"checkbox\" />",  
		"title" => _x('Service Item', 'post type singular name', 'nostalgia_service'),   
		"icon" => __('Icon', 'nostalgia_service'),
		"nostalgia_service_category" => __('Categories', 'nostalgia_service'),
		"date" => __('Date', 'nostalgia_service') 
	);

	return array_merge($new_columns, $columns);  
}  
add_filter("manage_edit-nostalgia_service_columns", "nostalgia_service_edit_columns");  

function manage_nostalgia_service_posts_custom_column($column)
{
	global $post;
	switch ($column)  
	{
		case "icon":   
			echo get_post_meta($post->ID, "icon", true);  
			break;
		case "nostalgia_service_category":
			echo get_the_term_list($post->ID, "nostalgia_service_category", '', ', ',''); 
			break;
	}  
}
add_action("manage_nostalgia_service_posts_custom_column", "manage_nostalgia_service_posts_custom_column");

//service
function nostalgia_service_shortcode($atts)
{
	extract(shortcode_atts(array(
		"category" => "",
	), $atts));
	
	$output = "";
	$output .= '<ul class="no-list list-service">';
	//get pages
	query_posts(array( 
		'post_type' => 'nostalgia_service',
		'posts_per_page' => '-1',
		'post_status' => 'publish',
		'nostalgia_service_category' => $category,
		'orderby' => 'menu_order', 
		'order' => 'ASC'
	));
	if(have_posts()) : while (have_posts()) : the_post();
		$icon = get_post_meta(get_the_ID(), "icon", true);
		$output .= '
		<li class="icon-big icon-' . $icon . '">
			<h3>' . get_the_title() . '</h3>
			<p>
				' . do_shortcode(get_the_content()) . '
			</p>
		</li>';
	endwhile; endif;
	$output .= '</ul>';
	return $output;
}
add_shortcode("nostalgia_service", "nostalgia_service_shortcode");
?>